@@ -242,7 +242,7 @@ class CPWord(MIDITokenizer):
         """
         assert time_division % max(self.beat_res.values()) == 0,\
             f'Invalid time division, please give one divisible by {max(self.beat_res.values())}'
-        events = self.tokens_to_events(tokens, multi_voc=True)
+        events = self.tokens_to_events(tokens)
 
         ticks_per_sample = time_division // max(self.beat_res.values())
         ticks_per_bar = time_division * 4
