@@ -232,7 +232,7 @@ class Octuple(MIDITokenizer):
             f'Invalid time division, please give one divisible by {max(self.beat_res.values())}'
         midi = MidiFile(ticks_per_beat=time_division)
         ticks_per_sample = time_division // max(self.beat_res.values())
-        events = self.tokens_to_events(tokens, multi_voc=True)
+        events = self.tokens_to_events(tokens)
 
         tempo_changes = [TempoChange(TEMPO, 0)]
         if self.additional_tokens['Tempo']:
@@ -421,7 +421,7 @@ class Octuple(MIDITokenizer):
                 current_pitches = {p: [] for p in self.programs}
 
             # Pitch
-            if pitch_value in current_pitches:
+            if pitch_value in current_pitches[program_value]:
                 has_error = True
             else:
                 current_pitches[program_value].append(pitch_value)
